@@ -1,4 +1,7 @@
+import sys
+
 from dagster import check
+from dagster.cli.workspace.context import IWorkspaceRequestContext
 from dagster.config.validate import validate_config_from_snap
 from dagster.core.host_representation import (
     ExternalExecutionPlan,
@@ -6,6 +9,7 @@ from dagster.core.host_representation import (
     PipelineSelector,
     RepositorySelector,
 )
+from dagster.utils.error import serializable_error_info_from_exc_info
 from graphql.execution.base import ResolveInfo
 
 from .utils import UserFacingGraphQLError, capture_error
@@ -58,9 +62,10 @@ def get_subset_external_pipeline(context, selector):
     repository_location = context.get_repository_location(selector.location_name)
     external_repository = repository_location.get_repository(selector.repository_name)
 
-    subset_result = repository_location.get_subset_external_pipeline_result(selector)
-    if not subset_result.success:
-        error_info = subset_result.error
+    try:
+        subset_result = repository_location.get_subset_external_pipeline_result(selector)
+    except Exception:  # pylint: disable=broad-except
+        error_info = serializable_error_info_from_exc_info(sys.exc_info())
         raise UserFacingGraphQLError(
             GrapheneInvalidSubsetError(
                 message="{message}{cause_message}".format(
@@ -120,13 +125,19 @@ def ensure_valid_step_keys(full_external_execution_plan, step_keys):
 
 
 def get_external_execution_plan_or_raise(
-    graphene_info, external_pipeline, mode, run_config, step_keys_to_execute
+    graphene_info,
+    external_pipeline,
+    mode,
+    run_config,
+    step_keys_to_execute,
+    known_state,
 ):
     full_external_execution_plan = graphene_info.context.get_external_execution_plan(
         external_pipeline=external_pipeline,
         run_config=run_config,
         mode=mode,
         step_keys_to_execute=None,
+        known_state=None,
     )
 
     if not step_keys_to_execute:
@@ -139,6 +150,7 @@ def get_external_execution_plan_or_raise(
         run_config=run_config,
         mode=mode,
         step_keys_to_execute=step_keys_to_execute,
+        known_state=known_state,
     )
 
 
@@ -178,26 +190,16 @@ def fetch_repository(graphene_info, repository_selector):
 
 
 @capture_error
-def fetch_repository_locations(graphene_info):
-    from ..schema.external import (
-        GrapheneRepositoryLocation,
-        GrapheneRepositoryLocationConnection,
-        GrapheneRepositoryLocationLoadFailure,
+def fetch_workspace(workspace_request_context):
+    from ..schema.external import GrapheneWorkspace, GrapheneWorkspaceLocationEntry
+
+    check.inst_param(
+        workspace_request_context, "workspace_request_context", IWorkspaceRequestContext
     )
 
-    check.inst_param(graphene_info, "graphene_info", ResolveInfo)
+    nodes = [
+        GrapheneWorkspaceLocationEntry(entry)
+        for entry in workspace_request_context.workspace_snapshot.values()
+    ]
 
-    nodes = []
-
-    for location_name in graphene_info.context.repository_location_names:
-        node = (
-            GrapheneRepositoryLocation(graphene_info.context.get_repository_location(location_name))
-            if graphene_info.context.has_repository_location(location_name)
-            else GrapheneRepositoryLocationLoadFailure(
-                location_name,
-                graphene_info.context.get_repository_location_error(location_name),
-            )
-        )
-        nodes.append(node)
-
-    return GrapheneRepositoryLocationConnection(nodes=nodes)
+    return GrapheneWorkspace(locationEntries=nodes)
