@@ -6,7 +6,7 @@ from snapshottest import Snapshot
 
 snapshots = Snapshot()
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_instance_in_process_env] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_in_memory_instance_lazy_repository] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -47,7 +47,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_i
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_instance_managed_grpc_env] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_in_memory_instance_managed_grpc_env] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -88,7 +88,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_i
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_instance_multi_location] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_in_memory_instance_multi_location] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -129,7 +129,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_in_memory_i
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_instance_deployed_grpc_env] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_sqlite_instance_deployed_grpc_env] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -170,7 +170,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_inst
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_instance_in_process_env] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_sqlite_instance_lazy_repository] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -211,7 +211,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_inst
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_instance_managed_grpc_env] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_sqlite_instance_managed_grpc_env] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
@@ -252,7 +252,7 @@ snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_inst
     }
 }
 
-snapshots['TestPresets.test_basic_preset_query_with_presets[readonly_sqlite_instance_multi_location] 1'] = {
+snapshots['TestPresets.test_basic_preset_query_with_presets[non_launchable_sqlite_instance_multi_location] 1'] = {
     'pipelineOrError': {
         'name': 'csv_hello_world',
         'presets': [
