@@ -137,6 +137,38 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'alp_a'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'alp_a'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'alp_b'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'alp_b'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -169,6 +201,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'backcompat_materialize'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'backcompat_materialization_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'backcompat_materialize'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -257,6 +305,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'emit'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'emit'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -305,6 +369,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'emit_ten'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'emit_ten'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -465,6 +545,46 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'multiply_by_two'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'double_total'
+                        }
+                    },
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'multiply_by_two'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'multiply_inputs'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'multiply_inputs'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -503,6 +623,14 @@ snapshots['test_query_all_solids 1'] = {
                     'name': 'noop_solid'
                 },
                 'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'noop_solid'
+                        }
+                    },
                     {
                         'pipeline': {
                             'name': 'more_complicated_config'
@@ -518,6 +646,14 @@ snapshots['test_query_all_solids 1'] = {
                         'solidHandle': {
                             'handleID': 'noop_solid'
                         }
+                    },
+                    {
+                        'pipeline': {
+                            'name': 'partitioned_asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'noop_solid'
+                        }
                     }
                 ]
             },
@@ -537,6 +673,38 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'palp_a'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'partitioned_asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'palp_a'
+                        }
+                    }
+                ]
+            },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'palp_b'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'partitioned_asset_lineage_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'palp_b'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -897,6 +1065,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'sum_numbers'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'dynamic_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'sum_numbers'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
@@ -969,6 +1153,22 @@ snapshots['test_query_all_solids 1'] = {
                     }
                 ]
             },
+            {
+                '__typename': 'UsedSolid',
+                'definition': {
+                    'name': 'tag_asset_solid'
+                },
+                'invocations': [
+                    {
+                        'pipeline': {
+                            'name': 'asset_tag_pipeline'
+                        },
+                        'solidHandle': {
+                            'handleID': 'tag_asset_solid'
+                        }
+                    }
+                ]
+            },
             {
                 '__typename': 'UsedSolid',
                 'definition': {
