@@ -1,9 +1,6 @@
-import sys
-
-import pytest
 from dagster_graphql.test.utils import execute_dagster_graphql, infer_pipeline_selector
 
-from .graphql_context_test_suite import ReadonlyGraphQLContextTestMatrix
+from .graphql_context_test_suite import NonLaunchableGraphQLContextTestMatrix
 from .setup import csv_hello_world_solids_config
 
 RUN_CONFIG_SCHEMA_QUERY = """
@@ -107,13 +104,16 @@ query PipelineQuery(
 """
 
 
-class TestEnvironmentSchema(ReadonlyGraphQLContextTestMatrix):
+class TestEnvironmentSchema(NonLaunchableGraphQLContextTestMatrix):
     def test_successful_run_config_schema(self, graphql_context):
         selector = infer_pipeline_selector(graphql_context, "multi_mode_with_resources")
         result = execute_dagster_graphql(
             graphql_context,
             RUN_CONFIG_SCHEMA_QUERY,
-            variables={"selector": selector, "mode": "add_mode",},
+            variables={
+                "selector": selector,
+                "mode": "add_mode",
+            },
         )
         assert result.data["runConfigSchemaOrError"]["__typename"] == "RunConfigSchema"
 
@@ -133,7 +133,10 @@ class TestEnvironmentSchema(ReadonlyGraphQLContextTestMatrix):
         result = execute_dagster_graphql(
             graphql_context,
             RUN_CONFIG_SCHEMA_QUERY,
-            variables={"selector": selector, "mode": "add_mode",},
+            variables={
+                "selector": selector,
+                "mode": "add_mode",
+            },
         )
         assert result.data["runConfigSchemaOrError"]["__typename"] == "InvalidSubsetError"
 
@@ -166,7 +169,6 @@ class TestEnvironmentSchema(ReadonlyGraphQLContextTestMatrix):
         )
         snapshot.assert_match(result.data)
 
-    @pytest.mark.skipif(sys.version_info < (3,), reason="Snapshot not working correctly on py2")
     def test_basic_invalid_config_on_run_config_schema(self, graphql_context, snapshot):
         selector = infer_pipeline_selector(graphql_context, "csv_hello_world")
         result = execute_dagster_graphql(
