@@ -14,12 +14,70 @@ from dagster_graphql.test.utils import execute_dagster_graphql
 
 from .graphql_context_test_suite import GraphQLContextVariant, make_graphql_context_test_suite
 
-# import dagster.api.utils
+RELOAD_REPOSITORY_LOCATION_QUERY = """
+mutation ($repositoryLocationName: String!) {
+   reloadRepositoryLocation(repositoryLocationName: $repositoryLocationName) {
+      __typename
+      ... on WorkspaceLocationEntry {
+        id
+        name
+        loadStatus
+        locationOrLoadError {
+            __typename
+            ... on RepositoryLocation {
+                name
+                repositories {
+                    name
+                    displayMetadata {
+                        key
+                        value
+                    }
+                }
+                isReloadSupported
+            }
+            ... on PythonError {
+                message
+            }
+        }
+      }
+   }
+}
+"""
+
+RELOAD_WORKSPACE_QUERY = """
+mutation {
+   reloadWorkspace {
+      __typename
+      ... on Workspace {
+        locationEntries {
+          __typename
+          id
+          name
+          loadStatus
+          locationOrLoadError {
+            __typename
+            ... on RepositoryLocation {
+                id
+                name
+                repositories {
+                    name
+                }
+                isReloadSupported
+            }
+            ... on PythonError {
+                message
+            }
+          }
+        }
+      }
+  }
+}
+"""
 
 
 class TestReloadWorkspace(
     make_graphql_context_test_suite(
-        context_variants=[GraphQLContextVariant.readonly_in_memory_instance_multi_location()]
+        context_variants=[GraphQLContextVariant.non_launchable_in_memory_instance_multi_location()]
     )
 ):
     def test_reload_workspace(self, graphql_context):
@@ -28,13 +86,15 @@ class TestReloadWorkspace(
         assert result
         assert result.data
         assert result.data["reloadWorkspace"]
-        assert result.data["reloadWorkspace"]["__typename"] == "RepositoryLocationConnection"
+        assert result.data["reloadWorkspace"]["__typename"] == "Workspace"
 
-        nodes = result.data["reloadWorkspace"]["nodes"]
+        nodes = result.data["reloadWorkspace"]["locationEntries"]
 
         assert len(nodes) == 2
 
-        assert all([node["__typename"] == "RepositoryLocation" for node in nodes])
+        assert all(
+            [node["locationOrLoadError"]["__typename"] == "RepositoryLocation" for node in nodes]
+        )
 
         original_origins = location_origins_from_yaml_paths(
             [file_relative_path(__file__, "multi_location.yaml")]
@@ -53,13 +113,19 @@ class TestReloadWorkspace(
             assert result
             assert result.data
             assert result.data["reloadWorkspace"]
-            assert result.data["reloadWorkspace"]["__typename"] == "RepositoryLocationConnection"
+            assert result.data["reloadWorkspace"]["__typename"] == "Workspace"
 
-            nodes = result.data["reloadWorkspace"]["nodes"]
+            nodes = result.data["reloadWorkspace"]["locationEntries"]
 
             assert len(nodes) == 1
 
-            assert all([node["__typename"] == "RepositoryLocation" for node in nodes])
+            assert all(
+                [
+                    node["locationOrLoadError"]["__typename"] == "RepositoryLocation"
+                    and node["loadStatus"] == "LOADED"
+                    for node in nodes
+                ]
+            )
 
             # Simulate adding an origin with an error, reload
 
@@ -79,17 +145,28 @@ class TestReloadWorkspace(
             assert result
             assert result.data
             assert result.data["reloadWorkspace"]
-            assert result.data["reloadWorkspace"]["__typename"] == "RepositoryLocationConnection"
+            assert result.data["reloadWorkspace"]["__typename"] == "Workspace"
 
-            nodes = result.data["reloadWorkspace"]["nodes"]
+            nodes = result.data["reloadWorkspace"]["locationEntries"]
             assert len(nodes) == 3
 
-            assert len([node for node in nodes if node["__typename"] == "RepositoryLocation"]) == 2
+            assert (
+                len(
+                    [
+                        node
+                        for node in nodes
+                        if node["locationOrLoadError"]["__typename"] == "RepositoryLocation"
+                        and node["loadStatus"] == "LOADED"
+                    ]
+                )
+                == 2
+            )
             failures = [
-                node for node in nodes if node["__typename"] == "RepositoryLocationLoadFailure"
+                node for node in nodes if node["locationOrLoadError"]["__typename"] == "PythonError"
             ]
             assert len(failures) == 1
             assert failures[0]["name"] == "error_location"
+            assert failures[0]["loadStatus"] == "LOADED"
 
             # Add another origin without an error, reload
 
@@ -98,12 +175,21 @@ class TestReloadWorkspace(
 
             result = execute_dagster_graphql(graphql_context, RELOAD_WORKSPACE_QUERY)
 
-            nodes = result.data["reloadWorkspace"]["nodes"]
+            nodes = result.data["reloadWorkspace"]["locationEntries"]
             assert len(nodes) == 4
 
-            assert len([node for node in nodes if node["__typename"] == "RepositoryLocation"]) == 3
+            assert (
+                len(
+                    [
+                        node
+                        for node in nodes
+                        if node["locationOrLoadError"]["__typename"] == "RepositoryLocation"
+                    ]
+                )
+                == 3
+            )
             failures = [
-                node for node in nodes if node["__typename"] == "RepositoryLocationLoadFailure"
+                node for node in nodes if node["locationOrLoadError"]["__typename"] == "PythonError"
             ]
             assert len(failures) == 1
 
@@ -116,12 +202,21 @@ class TestReloadWorkspace(
 
             result = execute_dagster_graphql(graphql_context, RELOAD_WORKSPACE_QUERY)
 
-            nodes = result.data["reloadWorkspace"]["nodes"]
+            nodes = result.data["reloadWorkspace"]["locationEntries"]
             assert len(nodes) == 4
 
-            assert len([node for node in nodes if node["__typename"] == "RepositoryLocation"]) == 3
+            assert (
+                len(
+                    [
+                        node
+                        for node in nodes
+                        if node["locationOrLoadError"]["__typename"] == "RepositoryLocation"
+                    ]
+                )
+                == 3
+            )
             failures = [
-                node for node in nodes if node["__typename"] == "RepositoryLocationLoadFailure"
+                node for node in nodes if node["locationOrLoadError"]["__typename"] == "PythonError"
             ]
             assert len(failures) == 1
 
@@ -130,7 +225,9 @@ class TestReloadWorkspace(
 
 class TestReloadRepositoriesOutOfProcess(
     make_graphql_context_test_suite(
-        context_variants=[GraphQLContextVariant.readonly_in_memory_instance_managed_grpc_env()]
+        context_variants=[
+            GraphQLContextVariant.non_launchable_in_memory_instance_managed_grpc_env()
+        ]
     )
 ):
     def test_out_of_process_reload_location(self, graphql_context):
@@ -141,26 +238,31 @@ class TestReloadRepositoriesOutOfProcess(
         assert result
         assert result.data
         assert result.data["reloadRepositoryLocation"]
-        assert result.data["reloadRepositoryLocation"]["__typename"] == "RepositoryLocation"
+        assert result.data["reloadRepositoryLocation"]["__typename"] == "WorkspaceLocationEntry"
         assert result.data["reloadRepositoryLocation"]["name"] == "test"
-        repositories = result.data["reloadRepositoryLocation"]["repositories"]
+        repositories = result.data["reloadRepositoryLocation"]["locationOrLoadError"][
+            "repositories"
+        ]
         assert len(repositories) == 1
         assert repositories[0]["name"] == "test_repo"
 
-        assert result.data["reloadRepositoryLocation"]["isReloadSupported"] is True
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["isReloadSupported"]
+            is True
+        )
 
         with mock.patch(
             # note it where the function is *used* that needs to mocked, not
             # where it is defined.
             # see https://docs.python.org/3/library/unittest.mock.html#where-to-patch
-            "dagster.core.host_representation.handle.sync_list_repositories_grpc"
+            "dagster.core.host_representation.repository_location.sync_list_repositories_grpc"
         ) as cli_command_mock:
 
             with mock.patch(
                 # note it where the function is *used* that needs to mocked, not
                 # where it is defined.
                 # see https://docs.python.org/3/library/unittest.mock.html#where-to-patch
-                "dagster.core.host_representation.handle.sync_get_streaming_external_repositories_data_grpc"
+                "dagster.core.host_representation.repository_location.sync_get_streaming_external_repositories_data_grpc"
             ) as external_repository_mock:
 
                 @repository
@@ -188,7 +290,9 @@ class TestReloadRepositoriesOutOfProcess(
                 assert cli_command_mock.call_count == 1
                 assert external_repository_mock.call_count == 1
 
-                repositories = result.data["reloadRepositoryLocation"]["repositories"]
+                repositories = result.data["reloadRepositoryLocation"]["locationOrLoadError"][
+                    "repositories"
+                ]
                 assert len(repositories) == 1
                 assert repositories[0]["name"] == "new_repo"
 
@@ -200,18 +304,26 @@ class TestReloadRepositoriesOutOfProcess(
         assert result
         assert result.data
         assert result.data["reloadRepositoryLocation"]
-        assert result.data["reloadRepositoryLocation"]["__typename"] == "RepositoryLocation"
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["__typename"]
+            == "RepositoryLocation"
+        )
         assert result.data["reloadRepositoryLocation"]["name"] == "test"
-        repositories = result.data["reloadRepositoryLocation"]["repositories"]
+        repositories = result.data["reloadRepositoryLocation"]["locationOrLoadError"][
+            "repositories"
+        ]
         assert len(repositories) == 1
         assert repositories[0]["name"] == "test_repo"
-        assert result.data["reloadRepositoryLocation"]["isReloadSupported"] is True
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["isReloadSupported"]
+            is True
+        )
 
         with mock.patch(
             # note it where the function is *used* that needs to mocked, not
             # where it is defined.
             # see https://docs.python.org/3/library/unittest.mock.html#where-to-patch
-            "dagster.core.host_representation.handle.sync_list_repositories_grpc"
+            "dagster.core.host_representation.repository_location.sync_list_repositories_grpc"
         ) as cli_command_mock:
             cli_command_mock.side_effect = Exception("Mocked repository load failure")
 
@@ -225,13 +337,13 @@ class TestReloadRepositoriesOutOfProcess(
             assert result.data
             assert result.data["reloadRepositoryLocation"]
             assert (
-                result.data["reloadRepositoryLocation"]["__typename"]
-                == "RepositoryLocationLoadFailure"
+                result.data["reloadRepositoryLocation"]["locationOrLoadError"]["__typename"]
+                == "PythonError"
             )
             assert result.data["reloadRepositoryLocation"]["name"] == "test"
             assert (
                 "Mocked repository load failure"
-                in result.data["reloadRepositoryLocation"]["error"]["message"]
+                in result.data["reloadRepositoryLocation"]["locationOrLoadError"]["message"]
             )
 
             # Verify failure is idempotent
@@ -245,13 +357,13 @@ class TestReloadRepositoriesOutOfProcess(
             assert result.data
             assert result.data["reloadRepositoryLocation"]
             assert (
-                result.data["reloadRepositoryLocation"]["__typename"]
-                == "RepositoryLocationLoadFailure"
+                result.data["reloadRepositoryLocation"]["locationOrLoadError"]["__typename"]
+                == "PythonError"
             )
             assert result.data["reloadRepositoryLocation"]["name"] == "test"
             assert (
                 "Mocked repository load failure"
-                in result.data["reloadRepositoryLocation"]["error"]["message"]
+                in result.data["reloadRepositoryLocation"]["locationOrLoadError"]["message"]
             )
 
         # can be reloaded again successfully
@@ -264,72 +376,27 @@ class TestReloadRepositoriesOutOfProcess(
         assert result
         assert result.data
         assert result.data["reloadRepositoryLocation"]
-        assert result.data["reloadRepositoryLocation"]["__typename"] == "RepositoryLocation"
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["__typename"]
+            == "RepositoryLocation"
+        )
         assert result.data["reloadRepositoryLocation"]["name"] == "test"
-        repositories = result.data["reloadRepositoryLocation"]["repositories"]
+        assert result.data["reloadRepositoryLocation"]["loadStatus"] == "LOADED"
+        repositories = result.data["reloadRepositoryLocation"]["locationOrLoadError"][
+            "repositories"
+        ]
         assert len(repositories) == 1
         assert repositories[0]["name"] == "test_repo"
-        assert result.data["reloadRepositoryLocation"]["isReloadSupported"] is True
-
-
-RELOAD_REPOSITORY_LOCATION_QUERY = """
-mutation ($repositoryLocationName: String!) {
-   reloadRepositoryLocation(repositoryLocationName: $repositoryLocationName) {
-      __typename
-      ... on RepositoryLocation {
-        name
-        repositories {
-          name
-          displayMetadata {
-            key
-            value
-          }
-        }
-        isReloadSupported
-      }
-      ... on RepositoryLocationLoadFailure {
-          name
-          error {
-              message
-          }
-      }
-   }
-}
-"""
-
-RELOAD_WORKSPACE_QUERY = """
-mutation {
-   reloadWorkspace {
-      __typename
-      ... on RepositoryLocationConnection {
-        nodes {
-          __typename
-          ... on RepositoryLocation {
-            id
-            name
-            repositories {
-              name
-            }
-            isReloadSupported
-          }
-          ... on RepositoryLocationLoadFailure {
-            id
-            name
-            error {
-              message
-            }
-          }
-        }
-      }
-    }
-}
-"""
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["isReloadSupported"]
+            is True
+        )
 
 
 class TestReloadRepositoriesManagedGrpc(
     make_graphql_context_test_suite(
         context_variants=[
-            GraphQLContextVariant.readonly_in_memory_instance_managed_grpc_env(),
+            GraphQLContextVariant.non_launchable_in_memory_instance_managed_grpc_env(),
         ]
     )
 ):
@@ -341,10 +408,16 @@ class TestReloadRepositoriesManagedGrpc(
         assert result
         assert result.data
         assert result.data["reloadRepositoryLocation"]
-        assert result.data["reloadRepositoryLocation"]["__typename"] == "RepositoryLocation"
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["__typename"]
+            == "RepositoryLocation"
+        )
         assert result.data["reloadRepositoryLocation"]["name"] == "test"
+        assert result.data["reloadRepositoryLocation"]["loadStatus"] == "LOADED"
 
-        repositories = result.data["reloadRepositoryLocation"]["repositories"]
+        repositories = result.data["reloadRepositoryLocation"]["locationOrLoadError"][
+            "repositories"
+        ]
         assert len(repositories) == 1
         assert repositories[0]["name"] == "test_repo"
 
@@ -357,4 +430,7 @@ class TestReloadRepositoriesManagedGrpc(
             or "package_name" in metadata_dict
         )
 
-        assert result.data["reloadRepositoryLocation"]["isReloadSupported"] is True
+        assert (
+            result.data["reloadRepositoryLocation"]["locationOrLoadError"]["isReloadSupported"]
+            is True
+        )
