@@ -1,6 +1,6 @@
 from dagster import DagsterEventType, check
+from dagster.cli.workspace.context import WorkspaceRequestContext
 from dagster_graphql.client.query import LAUNCH_PIPELINE_EXECUTION_MUTATION, SUBSCRIPTION_QUERY
-from dagster_graphql.implementation.context import DagsterGraphQLContext
 from dagster_graphql.test.utils import execute_dagster_graphql
 
 
@@ -9,7 +9,7 @@ def get_all_logs_for_finished_run_via_subscription(context, run_id):
     You should almost certainly ensure that this run has complete or terminated in order
     to get reliable results that you can test against.
     """
-    check.inst_param(context, "context", DagsterGraphQLContext)
+    check.inst_param(context, "context", WorkspaceRequestContext)
 
     run = context.instance.get_run_by_id(run_id)
 
@@ -37,7 +37,7 @@ def get_all_logs_for_finished_run_via_subscription(context, run_id):
 
 
 def sync_execute_get_payload(variables, context):
-    check.inst_param(context, "context", DagsterGraphQLContext)
+    check.inst_param(context, "context", WorkspaceRequestContext)
 
     result = execute_dagster_graphql(
         context, LAUNCH_PIPELINE_EXECUTION_MUTATION, variables=variables
@@ -55,13 +55,13 @@ def sync_execute_get_payload(variables, context):
 
 
 def sync_execute_get_run_log_data(variables, context):
-    check.inst_param(context, "context", DagsterGraphQLContext)
+    check.inst_param(context, "context", WorkspaceRequestContext)
     payload_data = sync_execute_get_payload(variables, context)
     return payload_data["pipelineRunLogs"]
 
 
 def sync_execute_get_events(variables, context):
-    check.inst_param(context, "context", DagsterGraphQLContext)
+    check.inst_param(context, "context", WorkspaceRequestContext)
     return sync_execute_get_run_log_data(variables, context)["messages"]
 
 
@@ -108,6 +108,7 @@ def step_did_fail_in_records(records, step_key):
         record.step_key == step_key
         and record.dagster_event.event_type_value == DagsterEventType.STEP_FAILURE.value
         for record in records
+        if record.is_dagster_event
     )
 
 
@@ -116,6 +117,7 @@ def step_did_succeed_in_records(records, step_key):
         record.step_key == step_key
         and record.dagster_event.event_type_value == DagsterEventType.STEP_SUCCESS.value
         for record in records
+        if record.is_dagster_event
     )
 
 
@@ -129,4 +131,5 @@ def step_did_not_run_in_records(records, step_key):
             DagsterEventType.STEP_SKIPPED.value,
         )
         for record in records
+        if record.is_dagster_event
     )
